Learn R Programming

betas (version 0.1.1)

betas.lmr: Compute standardized beta coeffizients for robust linear regression models

Description

Compute standardized beta coeffizients for robust linear regression models

Usage

betas.lmr(object, classic = FALSE)

Arguments

object
A model of class lmRob.
classic
Logical TRUE for classic covariance estimation.

Value

Vector with standardized beta coefficients.

Examples

Run this code
library(robust)
data <- pisa2012che

## robust estimation of betas
fit1 <- lmRob(MATH ~ ESCS, data)
betas.lmr(fit1)

## example where robust variance cannot be computed,
## instead the classical variance is used.
fit2 <- lmRob(MATH ~ ESCS + USEMATH, data)
betas.lmr(fit2)

Run the code above in your browser using DataLab